@@ -1,4 +1,4 @@
-binobp<-function(x,n,a = 1, b = 1 , ret = FALSE){
+binobp = function(x,n,a = 1, b = 1 , ret = FALSE){
 
   ## n - the number of trials in the binomial
   ## x - the number of observed successes
@@ -11,10 +11,10 @@ binobp<-function(x,n,a = 1, b = 1 , ret = FALSE){
   if(a<=0||b<=0)
     stop("The parameters of the prior must be greater than zero")
 
-  pi<-seq(0.01,0.999,by=0.001)
-  prior<-dbeta(pi,a,b)
-  likelihood<-dbinom(x,n,prob=pi)
-  posterior<-dbeta(pi,a+x,b+n-x)
+  pi = seq(0.01,0.999,by=0.001)
+  prior = dbeta(pi,a,b)
+  likelihood = dbinom(x,n,prob=pi)
+  posterior = dbeta(pi,a+x,b+n-x)
 
   plot(pi,posterior,ylim=c(0,1.1*max(posterior,prior)),type="l"
        ,lty=1
@@ -22,22 +22,22 @@ binobp<-function(x,n,a = 1, b = 1 , ret = FALSE){
        ,ylab="Density"
        ,col="blue")
   lines(pi,prior,lty=2,col="red")
-	
-  left<-min(pi)+diff(range(pi))*0.05
+
+  left = min(pi)+diff(range(pi))*0.05
   legend(left,max(posterior,prior),lty=1:2,legend=c("Posterior","Prior")
          ,col=c("blue","red"))
-	
-  m1<-(a+x)/(a+b+n)
-  v1<-m1*(1-m1)/(a+b+n+1)
-  s1<-sqrt(v1)
+
+  m1 = (a+x)/(a+b+n)
+  v1 = m1*(1-m1)/(a+b+n+1)
+  s1 = sqrt(v1)
 
   cat(paste("Posterior Mean           : ",round(m1,7),"\n"))
   cat(paste("Posterior Variance       : ",round(v1,7),"\n"))
   cat(paste("Posterior Std. Deviation : ",round(s1,7),"\n"))
 
-  probs<-c(0.005,0.01,0.025,0.05,0.5,0.95,0.975,0.99,0.995)
-  qtls<-qbeta(probs,a+x,b+n-x)
-  names(qtls)<-probs
+  probs = c(0.005,0.01,0.025,0.05,0.5,0.95,0.975,0.99,0.995)
+  qtls = qbeta(probs,a+x,b+n-x)
+  names(qtls) = probs
 
   cat("\nProb.\tQuantile \n")
   cat("------\t---------\n")
@@ -45,7 +45,11 @@ binobp<-function(x,n,a = 1, b = 1 , ret = FALSE){
     cat(paste(round(probs[i],3),"\t",round(qtls[i],7),"\n",sep=""))
 
 
-  if(ret)
-    return(list(posterior=posterior,likelihood=likelihood,prior=prior,pi=pi,mean=m1,var=v1,sd=s1,quantiles=qtls))
-	
+  if(ret){
+      cat("The argument ret is deprecated.\n")
+      cat("The results are now always returned invisibly\n")
+  }
+
+  invisible(list(posterior=posterior,likelihood=likelihood,prior=prior,pi=pi,mean=m1,var=v1,sd=s1,quantiles=qtls))
+
 }
